@@ -1,7 +1,17 @@
 
 #' Create geometries from vectors of coordinates
 #'
-#' @inheritParams wkutils::coords_point_translate_wkt
+#' These functions transform raw coordinates into point, line, polygon,
+#' features, or nest a vector of geometries into a MULTI* type or
+#' GEOMETRYCOLLECTION. See [wk::wk_coords()], [geos_unnest()], or
+#' [wk::wk_flatten()] to perform inverse operations; see [wk::xy()],
+#' [wk::wk_linestring()], [wk::wk_polygon()], or [wk::wk_collection()] for
+#' generic versions that work with non-GEOS types.
+#'
+#' @param x,y,z Vectors of coordinate values
+#' @param feature_id,ring_id Vectors for which a change in sequential values
+#'   indicates a new feature or ring. Use [factor()] to convert from a character
+#'   vector.
 #' @inheritParams geos_empty
 #' @inheritParams geos_write_wkt
 #'
@@ -100,6 +110,34 @@ geos_make_collection <- function(geom, type_id = "geometrycollection", feature_i
   }
 }
 
+#' Create rectangles from bounds
+#'
+#' @param xmin Left bound of envelope
+#' @param ymin Lower bound of envelope
+#' @param xmax Right bound of envelope
+#' @param ymax Upper bound of envelope
+#' @inheritParams as_geos_geometry
+#'
+#' @return A [geos_geometry()] consisting of a polygon
+#' @export
+#'
+geos_create_rectangle <- function(xmin, ymin, xmax, ymax,
+                                  crs = NULL) {
+  args <- lapply(list(xmin, ymin, xmax, ymax), as.numeric)
+  recycled <- recycle_common(args)
+
+  new_geos_geometry(
+    .Call(
+      geos_c_create_rectangle,
+      recycled[[1]],
+      recycled[[2]],
+      recycled[[3]],
+      recycled[[4]]
+    ),
+    crs = crs
+  )
+}
+
 
 #' Create empty geometries
 #'
@@ -109,7 +147,7 @@ geos_make_collection <- function(geom, type_id = "geometrycollection", feature_i
 #'   (default to calling [geos_type_id()]). This is most
 #'   usefully a character vector with the geometry type
 #'   (e.g., point, linestring, polygon).
-#' @inheritParams wk::wk_crs
+#' @inheritParams as_geos_geometry
 #'
 #' @return A [GEOS geometry vector][as_geos_geometry].
 #' @export
